C
C      ********************************************************
C      *                                                      *
C      *                   **** STLK1 ****                    *
C      *                                                      *
C      *   ONE-DIMENSIONAL MODEL OF STREAM-AQUIFER HYDRAULIC  *
C      *                                                      *
C      *      INTERACTION FOR CONFINED AND LEAKY AQUIFERS     *
C      *                                                      *
C      *         BOUNDED BY A FULLY PENETRATING STREAM        *
C      *                                                      *
C      *            VERSION CURRENT AS OF 09/01/98            *
C      *                                                      *
C      ********************************************************
C
C
C      Although this program has been used by the U.S. Geological
C      Survey, no warranty, expressed or implied, is made by the 
C      USGS as to the accuracy and functioning of the program and
C      related program material, nor shall the fact of distribution
C      constitute any such warranty, and no responsibility is
C      assumed by the USGS in connection therewith
C
C---SPECIFICATIONS
C
C---THE FOLLOWING CARD MUST BE CHANGED IF PROBLEM DIMENSIONS ARE
C   GREATER THAN 1,000. ALSO CHANGE VALUE OF IMAXX IN
C   SUBROUTINE DATAIO
      PARAMETER (IMAXX=1000)
C
      IMPLICIT DOUBLE PRECISION (A-H, O-Z)
      DIMENSION XTIME(IMAXX),STAGE(IMAXX),RECH(IMAXX)
      DIMENSION FH(IMAXX),FQ(IMAXX),H(IMAXX),SEEP(IMAXX),
     2 BANK(IMAXX),BANKV(IMAXX),SEEPT(IMAXX),HNET(IMAXX),
     3 QNET(IMAXX)
C
C---COMMON STATEMENTS
      COMMON /IOUNIT/ IN,IO,IP
      COMMON /PAR1/ ISTRESS,NT
      COMMON /PAR2/ IXL,IAQ,IXA,NS
      COMMON /PAR3/ XZERO,XLL,XSTREAM,XAA,DELT
      COMMON /PAR4/ AK,AS,AB
      COMMON /PAR5/ AKT,AST,ABT,ASYT
      COMMON /PAR6/ X,HINIT,TINIT
      COMMON /PAR7/ XTIME,STAGE,RECH
      COMMON /PAR8/ GAMMA1,SIGMA1,SIGMAP
      COMMON /PAR9/ XD,XLLD,XAAD
      COMMON /PAR10/ V(20),XLN2,EXPMAX
C
C1--OPEN INPUT, RESULT, AND PLOT FILES
      CALL OFILE(IPLOT)
C
C2--READ AND WRITE INPUT DATA
      CALL DATAIO
C
C3--DEFINE DIMENSIONLESS AND OTHER PARAMETERS
      ASC=AS*AB
      AT=AK*AB
      XZEROSQ=XZERO*XZERO
      XD=X/XZERO
      XZEROD=XZERO/AB
      IF(IXA.EQ.1)THEN
       XAAD=XAA/XZERO
      ELSE
       XAAD=0.0D0
      ENDIF
      IF(IXL.EQ.1)THEN
       XLLD=XLL/XZERO
      ELSE
       XLLD=0.0D0
      ENDIF
      IF(IAQ.GT.0)THEN
       GAMMA1=(XZERO/ABT)*DSQRT((AKT*ABT)/(AT))
       SIGMA1=(AST*ABT)/(AS*AB)
      ELSE
       GAMMA1=0.1D-03
       SIGMA1=0.1D-03
      ENDIF
      IF(IAQ.EQ.3)THEN
       SIGMAP=ASC/ASYT
      ELSE
       SIGMAP=0.0D0
      ENDIF
C
      WRITE(IO,100)
      WRITE(IO,101)XD
      WRITE(IO,102)XZEROD
      IF(IXL.EQ.0)WRITE(IO,103)
      IF(IXL.EQ.1)WRITE(IO,104)XLLD
      WRITE(IO,105)XAAD
      WRITE(IO,106)SIGMA1
      WRITE(IO,107)GAMMA1
      WRITE(IO,108)SIGMAP
C
C---EXPMAX IS THE MAXIMUM ALLOWABLE ABSOLUTE VALUE OF
C    EXPONENTIAL ARGUMENTS
       EXPMAX=708.D0
C
C4--CALL LINVST TO CALCULATE COEFFICIENTS USED FOR THE STEHFEST
C     ALGORITHM
       CALL LINVST(V,NS)
       XLN2=DLOG(2.D0)
C
      WRITE(IO,109)
      WRITE(*,110)
C
C5--INITIALIZE RESPONSE AND OTHER ARRAYS
       DO 5 I=1,NT
        H(I)=HINIT
        SEEP(I)=0.0D0
        SEEPT(I)=0.0D0
        BANK(I)=0.0D0
        BANKV(I)=0.0D0
        IF(ISTRESS.EQ.0)THEN
         HNET(I)=STAGE(I)
         QNET(I)=STAGE(I)
        ENDIF
        IF(ISTRESS.EQ.1)THEN
         HNET(I)=RECH(I)
         QNET(I)=-RECH(I)
        ENDIF
        IF(ISTRESS.EQ.2)THEN
         HNET(I)=STAGE(I)+RECH(I)
         QNET(I)=STAGE(I)-RECH(I)
        ENDIF
    5  CONTINUE
C
C6--CALCULATE THE TIME RATE OF CHANGE OF SYSTEM STRESS
       DO 10 I=2,NT
        FH(I-1)=(HNET(I)-HNET(I-1))/DELT
        FQ(I-1)=(QNET(I)-QNET(I-1))/DELT
   10  CONTINUE
C
C7--CALCULATE HEADS, SEEPAGE, AND BANK STORAGE USING CONVOLUTION
       DO 15 JT=1,NT-1
        SUMH=0.0D0
        SUMQ=0.0D0
       DO 20 KT=1,JT
        T=KT*DELT
        TD=(AK*T)/(AS*XZEROSQ)
C
C8--CALL LTST1 TO CALCULATE DIMENSIONLESS HEAD AND SEEPAGE
C   FOR DIMENSIONLESS TIME TD
        CALL LTST1(TD,HD,QD)
        SUMH=SUMH + FH(JT-KT+1)*HD
        SUMQ=SUMQ + FQ(JT-KT+1)*QD
   20  CONTINUE
C
        H(JT+1)=H(JT+1) + SUMH*DELT
        SEEP(JT+1)=SUMQ*(AK/XZEROD)*DELT
        SEEPT(JT+1)=2.0D0*SEEP(JT+1)*XSTREAM
        BANK(JT+1)=BANK(JT) - SEEP(JT+1)*DELT
        BANKV(JT+1)=2.0D0*BANK(JT+1)*XSTREAM
   15  CONTINUE
C
C9--WRITE RESULTS TO RESULT AND PLOT FILES
      WRITE(IO,111)
C
      IF(IPLOT.EQ.1)WRITE(IP,112)
C
      DO 80 I=1,NT
       T=TINIT+(I-1)*DELT
       WRITE(IO,113)T,H(I),SEEP(I),SEEPT(I),BANK(I),BANKV(I)
       IF(IPLOT.EQ.1)THEN
       WRITE(IP,114)T,H(I),SEEP(I),SEEPT(I),BANK(I),BANKV(I)
       ENDIF
  80   CONTINUE
C
C---FORMAT STATEMENTS
  100 FORMAT(/,/,14X,'DIMENSIONLESS PARAMETERS (CALCULATED BY', 
     2 ' PROGRAM)',/,14X,'-----------------------------------',
     3 '-------------',/)
  101 FORMAT(2X,' DIMENSIONLESS DISTANCE TO WELL (XD): ',
     2 20X,D10.3)
  102 FORMAT(2X,' DIMENSIONLESS DISTANCE TO STREAMBANK (XZEROD): ',
     2 10X,D10.3)
  103 FORMAT(2X,' DIMENSIONLESS WIDTH OF AQUIFER (XLLD): ',
     2 19X,' INFINITE')
  104 FORMAT(2X,' DIMENSIONLESS WIDTH OF AQUIFER (XLLD): ',
     2 18X,D10.3)
  105 FORMAT(2X,' DIMENSIONLESS STREAMBANK LEAKANCE (XAAD): ',
     2 15X,D10.3)
  106 FORMAT(2X,' DIMENSIONLESS RATIO OF AQUITARD TO AQUIFER',
     2 /,5X,' STORATIVITY (SIGMA1): ',32X,D10.3)
  107 FORMAT(2X,' DIMENSIONLESS RATIO OF AQUITARD TO AQUIFER HYDRAULIC',
     2 /,5X,' CONDUCTIVITY (GAMMA1): ',31X,D10.3)
  108 FORMAT(2X,' DIMENSIONLESS RATIO OF AQUIFER STORATIVITY',
     2 /,5X,' TO AQUITARD SPECIFIC YIELD (SIGMAP): ',17X,D10.3)
  109 FORMAT(/,/,/,38X,'RESULTS',/,38X,'-------',/)
  110 FORMAT(/,3X,'Calculating aquifer responses ...',/)
  111 FORMAT(/,43X,'TOTAL',7X,'BANK',5X,'BANK-STORAGE',/,
     2 6X,'TIME',9X,'HEAD',7X,'SEEPAGE',5X,'SEEPAGE',5X,'STORAGE',
     3 6X,'VOLUME',/,
     4 6X,'(T)',10X,'(L)',8X,'(L**2/T)',4X,'(L**3/T)',5X,'(L**2)',
     5 6X,'(L**3)',/,
     6 6X,'----',9X,'----',6X,'----------',2X,'----------',4X,
     7 '-------',6X,'------')
  112 FORMAT(8X,'T',12X,'H',10X,'SEEP',8X,'SEEPT',
     2 7X,'BANK',8X,'BANKV')
  113 FORMAT(1X,D13.6,2X,D11.5,2X,D10.4,2X,D10.4,2X,D10.4,
     2 2X,D10.4)
  114 FORMAT(1X,E13.6,2X,E11.5,2X,E10.4,2X,E10.4,2X,E10.4,
     2 2X,E10.4)
C
C10-CLOSE INPUT/RESULT/PLOT FILES, STOP, AND END
      CLOSE(UNIT=IN)
      CLOSE(UNIT=IO)
      IF(IPLOT.EQ.1)CLOSE(UNIT=IP)
      STOP
      END
C
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE OFILE                    *
C      *                                                      *
C      *            VERSION CURRENT AS OF 09/01/98            *
C      *                                                      *
C       ******************************************************
C
C11-SUBROUTINE OFILE OPENS INPUT, RESULT, AND PLOT FILES
C
      SUBROUTINE OFILE(IPLOT)
C
C---SPECIFICATIONS
      CHARACTER*50 IFNAME, OFNAME, PFNAME
      INTEGER IN, IO, IP, N, IPLOT
      COMMON /IOUNIT/ IN,IO,IP
C
      IN = 15
      IO = 16
      IP = 17
C
C---Write banner to screen:
      WRITE(*,8)
C
C---READ INPUT, RESULT, AND PLOT FILE NAMES
   10 WRITE(*,2)
      READ(*,5) IFNAME
      N=LENCHR(IFNAME)
      IF(N.LT.1) GO TO 10
      OPEN(IN,FILE=IFNAME,STATUS='OLD')
C
   11 WRITE(*,3)
      READ(*,5) OFNAME
      N=LENCHR(OFNAME)
      IF(N.LT.1) GO TO 11
      OPEN(IO,FILE=OFNAME)
C
      WRITE(*,4)
      READ(*,5) PFNAME
      N=LENCHR(PFNAME)
      IF(N.LT.1)THEN
       IPLOT=0
       WRITE(*,6)
      ELSE
       IPLOT=1
       OPEN(IP,FILE=PFNAME)
      ENDIF
C
      WRITE(*,7)
C
C---FORMAT STATEMENTS
    2 FORMAT(3X,'Enter name of file containing input data:')
    3 FORMAT(3X,'Enter name of file for program results:')
    4 FORMAT(3X,'Enter name of plot file (return for no plot file):')
    5 FORMAT(A50)
    6 FORMAT(/,3X,'No plot file specified. Results will not be written',
     1' to a plot file.')
    7 FORMAT(/,3X,'File names have been read.')
C---Update 11/24/2009: add FORMAT statement:
    8 FORMAT(10X,'   STLK1 version 1.0, November 24, 2009',/,
     1 3X, 'Computer Program for Analysis of Hydraulic Interaction',/,
     2 7X, ' Between a Stream and Confined or Leaky Aquifer',/)
C
C---RETURN AND END
      RETURN
      END
C
C       ******************************************************
C      *                                                      *
C      *                    FUNCTION LENCHR                   *
C      *                                                      *
C      *            VERSION CURRENT AS OF 09/01/98            *
C      *                                                      *
C       ******************************************************
C
C12-FUNCTION LENCHR CALCULATES THE LENGTH OF A CHARACTER STRING
C   (CODE FROM R. STEVE REGAN, USGS)
C
      INTEGER FUNCTION LENCHR
     I                       ( STRING )
C
      CHARACTER*(*) STRING
C
C     + + + ARGUMENT DEFINITIONS + + +
C     STRING - Input string to determine length of
C
C     + + + LOCAL VARIABLES + + +
      INTEGER MAX, I
C
C     + + + INTRINSICS + + +
      INTEGER LEN
      INTRINSIC LEN
C
C     + + + END SPECIFICATIONS + + +
C
      MAX = LEN(STRING)
      DO 10 I = MAX, 1, -1
        IF (STRING(I:I).NE.' ') THEN
          LENCHR = I
          GOTO 20
        ENDIF
   10 CONTINUE
      LENCHR = 0
C
   20 RETURN
      END
C
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE DATAIO                   *
C      *                                                      *
C      *            VERSION CURRENT AS OF 09/01/98            *
C      *                                                      *
C       ******************************************************
C
C13-SUBROUTINE DATAIO READS INPUT DATA FROM THE INPUT FILE AND
C   WRITES THIS DATA TO THE RESULT FILE
C
      SUBROUTINE DATAIO
C
C---SPECIFICATIONS
C
C---THE FOLLOWING CARD MUST BE CHANGED IF PROBLEM DIMENSIONS ARE
C   GREATER THAN 1,000. ALSO CHANGE VALUE OF IMAXX IN
c   MAIN PROGRAM
      PARAMETER (IMAXX=1000)
C
      IMPLICIT DOUBLE PRECISION (A-H, O-Z)
      DIMENSION XTIME(IMAXX),STAGE(IMAXX),RECH(IMAXX)
      CHARACTER STRING*80,TITLE1*70,TITLE2*70               
C
C---COMMON STATEMENTS
      COMMON /IOUNIT/ IN,IO,IP
      COMMON /PAR1/ ISTRESS,NT
      COMMON /PAR2/ IXL,IAQ,IXA,NS
      COMMON /PAR3/ XZERO,XLL,XSTREAM,XAA,DELT
      COMMON /PAR4/ AK,AS,AB
      COMMON /PAR5/ AKT,AST,ABT,ASYT
      COMMON /PAR6/ X,HINIT,TINIT
      COMMON /PAR7/ XTIME,STAGE,RECH
C
C13a-WRITE PROGRAM BANNER TO RESULT FILE
      CALL BANNER(IO)
C
C13b-READ INPUT DATA
      READ(IN,'(A80)') STRING
      ILINE=1
      READ(STRING,99,ERR=1000) TITLE1
C
      READ(IN,'(A80)') STRING
      ILINE=2
      READ(STRING,99,ERR=1000) TITLE2
C
      READ(IN,'(A80)') STRING
      ILINE=3
      READ(STRING,*,ERR=1000) ISTRESS, DELT, IPRINT
C
      READ(IN,'(A80)') STRING
      ILINE=4
      READ(STRING,*,ERR=1000) IXL, IAQ, IXA 
C
      READ(IN,'(A80)') STRING
      ILINE=5
      READ(STRING,*,ERR=1000) XZERO, XLL, XAA, XSTREAM
C
      READ(IN,'(A80)') STRING
      ILINE=6
      READ(STRING,*,ERR=1000) AK, AS, AB
C
      READ(IN,'(A80)') STRING
      ILINE=7
      READ(STRING,*,ERR=1000) AKT, AST, ABT, ASYT
C
      READ(IN,'(A80)') STRING
      ILINE=8
      READ(STRING,*,ERR=1000) X, HINIT, TINIT
C
      READ(IN,'(A80)') STRING
      ILINE=9
      READ(STRING,*,ERR=1000) NS

      READ(IN,'(A80)') STRING
      ILINE=10
      READ(STRING,*,ERR=1000) NT
C
C13c-READ STRESS DATA
       DO 10 ID=1,NT
         READ(IN,'(A80)') STRING
         ILINE=11
         READ(STRING,*,ERR=1000) XTIME(ID), STAGE(ID), RECH(ID)
  10   CONTINUE
C
C13d-WRITE INPUT DATA TO RESULT FILE
C
C---LINES 1 AND 2
      WRITE(IO,100)TITLE1
      WRITE(IO,100)TITLE2
C
      WRITE(IO,101)
C
C---LINE 3
      IF(ISTRESS.EQ.0)WRITE(IO,102)ISTRESS
      IF(ISTRESS.EQ.1)WRITE(IO,103)ISTRESS
      IF(ISTRESS.EQ.2)WRITE(IO,104)ISTRESS
      IF(ISTRESS.GT.2.OR.ISTRESS.LT.0)THEN
       WRITE(IO,105)
       STOP
      ENDIF
      IF(ISTRESS.EQ.1.OR.ISTRESS.EQ.2)THEN
       IF(IAQ.NE.3)THEN
        WRITE(IO,106)
        STOP
       ENDIF
      ENDIF
C
      WRITE(IO,107)DELT
C
      IF(IPRINT.EQ.0)WRITE(IO,108)IPRINT
      IF(IPRINT.EQ.1)WRITE(IO,109)IPRINT
      IF(IPRINT.GT.1)THEN
       WRITE(IO,110)
       STOP
      ENDIF
C
C---LINES 4 AND 5
      WRITE(IO,111)
C
      IF(IXL.EQ.0)WRITE(IO,112)IXL
      IF(IXL.EQ.1)WRITE(IO,113)IXL
      IF(IXL.GT.1)THEN
       WRITE(IO,114)
       STOP
      ENDIF
C
      IF(IAQ.EQ.0)WRITE(IO,115)IAQ
      IF(IAQ.EQ.1)WRITE(IO,116)IAQ
      IF(IAQ.EQ.2)WRITE(IO,117)IAQ
      IF(IAQ.EQ.3)WRITE(IO,118)IAQ
      IF(IAQ.GT.3)THEN
        WRITE(IO,119)
        STOP
      ENDIF
C
      IF(IXA.EQ.0)WRITE(IO,120)IXA
      IF(IXA.EQ.1)WRITE(IO,121)IXA
      IF(IXA.GT.1)THEN
       WRITE(IO,122)
       STOP
      ENDIF
C
      WRITE(IO,123)XZERO
      IF(XZERO.LE.0.0D0)THEN
        WRITE(IO,124)
        STOP
      ENDIF
C
      IF(IXL.EQ.1)WRITE(IO,125)XLL
      IF(IXL.EQ.1)THEN
       IF(XLL.LE.0.0D0)THEN
        WRITE(IO,126)
        STOP
       ENDIF
      ENDIF
C
      IF(IXA.EQ.1)WRITE(IO,127)XAA
      IF(IXA.EQ.1)THEN
       IF(XAA.LE.0.0D0)THEN
        WRITE(IO,128)
        STOP
       ENDIF
      ENDIF
C
      WRITE(IO,129)XSTREAM
      IF(XSTREAM.LE.0.0D0)THEN
       WRITE(IO,130)
       STOP
      ENDIF
C
C---LINE 6
      WRITE(IO,131)
C
      WRITE(IO,132)AK
      WRITE(IO,133)AS
      WRITE(IO,134)AB
      IF(AK.LE.0.0D0)THEN
       WRITE(IO,135)
       STOP
      ENDIF
      IF(AS.LE.0.0D0)THEN
       WRITE(IO,135)
       STOP
      ENDIF
      IF(AB.LE.0.0D0)THEN
       WRITE(IO,135)
       STOP
      ENDIF
C
C---LINE 7
      WRITE(IO,136)
C
      WRITE(IO,137)AKT
      WRITE(IO,138)AST
      WRITE(IO,139)ABT
      WRITE(IO,140)ASYT
      IF(IAQ.GT.0)THEN
       IF(AKT.LE.0.0D0)THEN
        WRITE(IO,141)
        STOP
       ENDIF
       IF(AST.LE.0.0D0)THEN
        WRITE(IO,141)
        STOP
       ENDIF
       IF(ABT.LE.0.0D0)THEN
        WRITE(IO,141)
        STOP
       ENDIF
      ENDIF
      IF(IAQ.EQ.3)THEN
       IF(ASYT.LE.0.0D0)THEN
        WRITE(IO,142)
        STOP
       ENDIF
      ENDIF
C
C---LINE 8
      WRITE(IO,143)
C
      WRITE(IO,144)X
      WRITE(IO,145)HINIT
      WRITE(IO,146)TINIT
C
C---LINE 9
      WRITE(IO,147)
      WRITE(IO,148)NS
C
C---LINES 10 AND HIGHER
      WRITE(IO,149)
      WRITE(IO,150)NT
C
      IF(IPRINT.EQ.0)WRITE(IO,151)
C 
      IF(IPRINT.EQ.1)THEN
       WRITE(IO,152)
       DO 35 ID=1,NT
        WRITE(IO,153)XTIME(ID),STAGE(ID),RECH(ID)
  35   CONTINUE
      ENDIF
C
C---FORMAT STATEMENTS
   99 FORMAT(A70)
  100 FORMAT(5X,A70)
  101 FORMAT(/,/,20X,'SUMMARY OF INPUT DATA',
     2/,20X,'---------------------'/)
  102 FORMAT(2X,' STRESS TYPE (ISTRESS): ',10X,I5,
     2' (stream-stage fluctuations)')
  103 FORMAT(2X,' STRESS TYPE (ISTRESS): ',10X,I5,
     2' (recharge/leakage)')
  104 FORMAT(2X,' STRESS TYPE (ISTRESS): ',10X,I5,
     2' (stream-stage and recharge/leakage)')
  105 FORMAT(2X,' ISTRESS NOT EQUAL TO 0, 1, OR 2. PROGRAM STOPPED')
  106 FORMAT(/,2X,' ISTRESS EQUALS 1 OR 2 (RECHARGE) AND AQUIFER',
     2' IS NOT LEAKY WITH WATER-TABLE',/,2X,' AQUITARD. RECHARGE IS',
     3' SIMULATED ONLY WHEN A WATER TABLE IS PRESENT.',/,2X,
     4' PROGRAM STOPPED.')
  107 FORMAT(2X,' TIME-STEP SIZE (DELT):',12X,D12.3,' (units of time)')
  108 FORMAT(2X,' PRINTING CODE (IPRINT): ',9X,I5,
     2' (stress data not printed)')
  109 FORMAT(2X,' PRINTING CODE (IPRINT): ',9X,I5,
     2' (stress data printed)')
  110 FORMAT(3X,'PRINTING CODE (IPRINT) IS INVALID. PROGRAM STOPPED.')
  111 FORMAT(/,' AQUIFER AND STREAMBANK CHARACTERISTICS
     2 (INPUT LINES 4 AND 5)')
  112 FORMAT(2X,' AQUIFER EXTENT (IXL): ',11X,I5,
     2' (semi infinite)')
  113 FORMAT(2X,' AQUIFER EXTENT (IXL): ',11X,I5,
     2' (finite width)')
  114 FORMAT(3X,'AQUIFER EXTENT (IXL) IS INVALID. PROGRAM STOPPED.')
  115 FORMAT(2X,' AQUIFER TYPE (IAQ): ',13X,I5,
     2' (confined)')
  116 FORMAT(2X,' AQUIFER TYPE (IAQ): ',13X,I5,
     2' (leaky, with constant head)')
  117 FORMAT(2X,' AQUIFER TYPE (IAQ): ',13X,I5,
     2' (leaky, with impervious layer)')
  118 FORMAT(2X,' AQUIFER TYPE (IAQ): ',13X,I5,
     2' (leaky, with water-table aquitard)')
  119 FORMAT(3X,'AQUIFER TYPE (IAQ) IS INVALID. PROGRAM STOPPED.') 
  120 FORMAT(2X,' STREAMBANK CODE (IXA): ',10X,I5,
     2' (semipervious streambank absent)')
  121 FORMAT(2X,' STREAMBANK CODE (IXA): ',10X,I5,
     2' (semipervious streambank simulated)')
  122 FORMAT(3X,'STREAMBANK CODE (IXA) INVALID. PROGRAM STOPPED.')
  123 FORMAT(2X,' STREAM HALF WIDTH (XZERO): ',7X,D12.3,
     2' (units of length)')
  124 FORMAT(3X,'STREAM HALF WIDTH (XZERO) IS LESS THAN OR EQUAL',
     2 ' TO ZERO. PROGRAM STOPPED')
  125 FORMAT(2X,' WIDTH OF AQUIFER (XLL): ',10X,D12.3,
     2' (units of length)')
  126 FORMAT(3X,'AQUIFER WIDTH (XLL) LESS THAN OR EQUAL TO ZERO.',
     2 ' PROGRAM STOPPED.')
  127 FORMAT(2X,' STREAMBANK LEAKANCE (XAA): ',9X,D10.3,
     2' (units of length)')
  128 FORMAT(3X,'STREAMBANK LEAKANCE (XAA) LESS THAN OR EQUAL',
     2' TO ZERO.',/,5X,' PROGRAM STOPPED.')
  129 FORMAT(2X,' LENGTH OF STREAM (XSTREAM): ',6X,D12.3,
     2' (units of length)')
  130 FORMAT(3X,'STREAM LENGTH (XSTREAM) IS LESS THAN OR EQUAL TO',
     2' ZERO. PROGRAM STOPPED.')
  131 FORMAT(/,' AQUIFER PROPERTIES (INPUT LINE 6) ')
  132 FORMAT(2X,' HYDRAULIC CONDUCTIVITY (AK): ',5X,D12.3,
     2' (units of length per time)')
  133 FORMAT(2X,' SPECIFIC STORAGE (AS): ',11X,D12.3,
     2' (units of inverse length)')
  134 FORMAT(2X,' SATURATED THICKNESS (AB): ',8X,D12.3,
     2' (units of length)')
  135 FORMAT(3X,'A HYDRAULIC PROPERTY OF THE AQUIFER (INPUT LINE 6)',
     2 ' IS LESS THAN OR',/,5X,' EQUAL TO ZERO. PROGRAM STOPPED.')
  136 FORMAT(/,' AQUITARD PROPERTIES (INPUT LINE 7) ')
  137 FORMAT(2X,' HYDRAULIC CONDUCTIVITY (AKT): ',4X,D12.3,
     2' (units of length per time)')
  138 FORMAT(2X,' SPECIFIC STORAGE (AST): ',10X,D12.3,
     2' (units of inverse length)')
  139 FORMAT(2X,' SATURATED THICKNESS (ABT): ',7X,D12.3,
     2' (units of length)')
  140 FORMAT(2X,' SPECIFIC YIELD (ASYT): ',11X,D12.3,
     2' (dimensionless)')
  141 FORMAT(3X,'A HYDRAULIC PROPERTY OF THE AQUITARD (INPUT LINE 7)',
     2 ' IS LESS THAN OR',/,5X,' EQUAL TO ZERO. PROGRAM STOPPED.')
  142 FORMAT(3X,'SPECIFIC YIELD OF THE AQUITARD (ASYT) IS LESS THAN',
     2' OR EQUAL',/,5X,' TO ZERO. PROGRAM STOPPED.')
  143 FORMAT(/,' OBSERVATION WELL DATA AND INITIAL CONDITIONS
     2 (INPUT LINE 8)')
  144 FORMAT(2X,' DISTANCE TO OBSERVATION WELL (X): ',D10.3,
     2' (units of length)')
  145 FORMAT(2X,' INITIAL HEAD AT WELL (HINIT): ',2X,D12.3,
     2' (units of length)')
  146 FORMAT(2X,' START TIME OF SIMULATION (TINIT): ',D10.3,
     2' (units of time)')
  147 FORMAT(/,' PROGRAM SOLUTION VARIABLES (INPUT LINE 9) ')
  148 FORMAT(2X,' NUMBER OF STEHFEST TERMS (NS): ',12X,I5)
  149 FORMAT(/,/,20X,'SUMMARY OF STRESS DATA',/,
     2 20X,'----------------------')
  150 FORMAT(/,2X,' NUMBER OF SPECIFIED TIME STEPS (NT): ',9X,I5)
  151 FORMAT(2X,' STRESS DATA NOT PRINTED ')
  152 FORMAT(/,10X,'TIME        STAGE         RECH',/,
     2'          ----        -----         ----')
  153 FORMAT(7X,D10.4,3X,D10.4,3X,D10.4)
C
      RETURN
C---CALL RDERR FOR INPUT READ ERRORS
 1000 CALL RDERR(IO,STRING,ILINE)
      END
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE BANNER                   *
C      *                                                      *
C      *            VERSION CURRENT AS OF 09/01/98            *
C      *                                                      *
C       ******************************************************
C
C14-SUBROUTINE BANNER WRITES A PROGRAM BANNER TO RESULT FILE
C
      SUBROUTINE BANNER(IO)
      WRITE(IO,100)
 100  FORMAT(/,10X,
     2'      *****************************************************',/,
     3 10X,
     4'      *                                                   *',/,
     5 10X,
     6'      *         ****  U.S. GEOLOGICAL SURVEY  ****        *',/,
     7 10X,
     8'      *                                                   *',/,
     9 10X,
     &'      *          **** STLK1: PROGRAM OUTPUT ****          *',/,
     1 10X,
     2'      *                                                   *',/,
     3 10X,
     4'      * ONE-DIMENSIONAL MODEL OF STREAM-AQUIFER HYDRAULIC *',/,
     5 10X,
     6'      *                                                   *',/,
     7 10X,
     8'      *    INTERACTION FOR CONFINED AND LEAKY AQUIFERS    *',/,
     9 10X,
     &'      *                                                   *',/,
     1 10X,
     2'      *       BOUNDED BY A FULLY PENETRATING STREAM       *',/,
     3 10X,
     4'      *                                                   *',/,
     5 10X,
     6'      *           VERSION CURRENT AS OF 09/01/98          *',/,
     7 10X,
     8'      *                                                   *',/,
     9 10X,
     &'      *****************************************************',
     1/,/)
C
      RETURN
      END
C
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE RDERR                    *
C      *                                                      *
C      *            VERSION CURRENT AS OF 09/01/98            *
C      *                                                      *
C       ******************************************************
C
C15-SUBROUTINE RDERR WRITES AN ERROR MESSAGE TO THE RESULT FILE
C   AND STOPS PROGRAM EXECUTION
C
      SUBROUTINE RDERR(IO,STRING,ILINE)
C
C---SPECIFICATIONS
      CHARACTER STRING*80,VAR(11)*40
      DATA VAR/' TITLE1',
     2         ' TITLE2',
     3         ' ISTRESS  DELT  IPRINT',
     4         ' IXL  IAQ  IXA',
     5         ' XZERO  XLL  XAA  XSTREAM',
     6         ' AK  AS  AB',
     7         ' AKT  AST  ABT  ASYT',
     8         ' X  HINIT  TINIT',
     9         ' NS',
     &         ' NT',
     1         ' TIME-STRESS DATA'/
C
      WRITE(IO,1)ILINE
      WRITE(IO,'(A80)')STRING
      WRITE(IO,2) VAR(ILINE)
      WRITE(IO,3)

   1  FORMAT(' Aborting due to error in line from input file:',
     2 2X,I5)
   2  FORMAT(' While attempting to read variables',A40)
   3  FORMAT(' Check for incorrect positions or data types...')
      STOP
      END
C
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE LINVST                   *
C      *                                                      *
C      *            VERSION CURRENT AS OF 09/01/98            *
C      *                                                      *
C       ******************************************************
C
C16-SUBROUTINE LINVST CALCULATES COEFFICIENTS USED FOR THE
C   STEHFEST ALGORITHM
C
       SUBROUTINE LINVST(V,NS)
C
C---SPECIFICATIONS
       IMPLICIT DOUBLE PRECISION (A-H,O-Z)
       DIMENSION G(20),V(20),HS(20)
C
       G(1)=1.D0
       NH=NS/2
        DO 1 IS=2,NS
1      G(IS)=G(IS-1)*IS
       HS(1)=2.D0/G(NH-1)
        DO 3 IS=2,NH
       FI=IS
       IF(IS.EQ.NH) GO TO 2
       HS(IS)=FI**(NH)*G(2*IS)/(G(NH-IS)*G(IS)*G(IS-1))
       GO TO 3
2      HS(IS)=FI**(NH)*G(2*IS)/(G(IS)*G(IS-1))
3       CONTINUE
       SN=2*(NH-NH/2*2)-1
        DO 4 IS=1,NS
       V(IS)=0.D0
       K1=(IS+1)/2
       K2=IS
       IF(K2.GT.NH)K2=NH
        DO 5 KS=K1,K2
       IF(2*KS-IS.EQ.0) GO TO 6
       IF(IS.EQ.KS)GO TO 7
       V(IS)=V(IS)+HS(KS)/(G(IS-KS)*G(2*KS-IS))
       GO TO 5
6      V(IS)=V(IS)+HS(KS)/(G(IS-KS))
       GO TO 5
7      V(IS)=V(IS)+HS(KS)/G(2*KS-IS)
5       CONTINUE
       V(IS)=SN*V(IS)
       SN=-SN
4       CONTINUE
       RETURN
       END
C
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE LTST1                    *
C      *                                                      *
C      *            VERSION CURRENT AS OF 09/01/98            *
C      *                                                      *
C       ******************************************************
C
C17-SUBROUTINE LTST1 CALCULATES THE LAPLACE TRANSFORM SOLUTIONS 
C   FOR HEADS AND SEEPAGE FOR CONFINED AND LEAKY AQUIFERS BOUNDED 
C   BY A FULLY PENETRATING STREAM. AQUIFERS MAY BE SEMI-INFINITE
C   OR FINITE WIDTH AND MAY INCLUDE A SEMI-PERVIOUS STREAMBANK.
C
       SUBROUTINE LTST1(TD,HDT,QTD)
C
C---SPECIFICATIONS
       IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      COMMON /PAR2/ IXL,IAQ,IXA,NS
      COMMON /PAR8/ GAMMA1,SIGMA1,SIGMAP
      COMMON /PAR9/ XD,XLLD,XAAD
      COMMON /PAR10/ V(20),XLN2,EXPMAX
C
       XP=0.D0
       XPQ=0.D0
      DO 1 I=1,NS
       PP=XLN2*I/TD
C
C17a-CALCULATE GAMMA1 SQUARED AND VARIABLE M FOR LEAKY CONDITIONS
       IF(IAQ.GT.0)THEN
        GAM1SQ=GAMMA1*GAMMA1
        XM=SIGMA1*PP/GAM1SQ
        SQRTM=DSQRT(XM)
       ENDIF
C
C17b-CALCULATE QD TERM FOR LEAKY CONDITION
C       IAQ = 0, CONFINED AQUIFER
C       IAQ = 1, LEAKY AQUIFER, CONSTANT HEAD IN SOURCE BED
C       IAQ = 2, LEAKY AQUIFER, OVERLYING IMPERVIOUS LAYER 
C       IAQ = 3, LEAKY AQUIFER, WATER-TABLE AQUITARD
C
       IF(IAQ.EQ.0) QD=0.D0
       IF(IAQ.EQ.1) QD=GAM1SQ*SQRTM/DTANH(SQRTM)
       IF(IAQ.EQ.2) QD=GAM1SQ*SQRTM*DTANH(SQRTM)
       IF(IAQ.EQ.3) THEN
         XNUM=SQRTM*(GAM1SQ)*DTANH(SQRTM) + PP/SIGMAP
         XDEN=SQRTM*(GAM1SQ) + PP/SIGMAP*DTANH(SQRTM)
         QD=GAM1SQ*SQRTM*XNUM/XDEN
       ENDIF
C
C17c-CALCULATE COEFFICIENTS FOR SEEPAGE TERM 
       C1=DSQRT(PP+QD)
       C2=PP*(1.D0+C1*XAAD)
       CAQ=-C1/C2
C
C17d-CALCULATE WIDTH TERM.
C     IF SEMI-INFINITE AQUIFER, F = 1.0:
       IF(IXL.EQ.0) FF=1.D0
C     IF FINITE-WIDTH AQUIFER, F IS CALCULATED:
       IF(IXL.EQ.1) THEN
        FNUM=1.D0+DEXP(-2.D0*C1*(XLLD-XD))
        FDEN=1.D0+DEXP(-2.D0*C1*(XLLD-1.D0))
        FF=FNUM/FDEN
        C2=PP*(1.D0+C1*XAAD*DTANH(C1*(XLLD-1.D0)))
        C3=FDEN
        C4=C2*C3
        CAQ=-(C1/C4)*(1.D0-DEXP(-2.D0*C1*(XLLD-1.D0)))
       ENDIF
C
       CA=C1*(XD-1.D0)
       IF(CA.GT.EXPMAX) CA=EXPMAX
C
C17e-CALCULATE HEAD AND SEEPAGE TERMS
       RE0=FF*DEXP(-CA)
       RE0Q=CAQ
       PDL=RE0/C2
       PDLQ=RE0Q
      XP=XP+V(I)*PDL
1     XPQ=XPQ+V(I)*PDLQ
       HDT=XP*XLN2/TD
       QTD=XPQ*XLN2/TD
C
C17f-RETURN TO MAIN PROGRAM
       RETURN
       END
C
