C
C      ********************************************************
C      *                                                      *
C      *                   **** STWT1 ****                    *
C      *                                                      *
C      *   TWO-DIMENSIONAL MODEL OF STREAM-AQUIFER HYDRAULIC  *
C      *                                                      *
C      *   INTERACTION FOR CONFINED AND WATER-TABLE AQUIFERS  *
C      *                                                      *
C      *         BOUNDED BY A FULLY PENETRATING STREAM        *
C      *                                                      *
C      *            VERSION CURRENT AS OF 09/01/98            *
C      *                                                      *
C      ********************************************************
C
C
C      Although this program has been used by the U.S. Geological
C      Survey, no warranty, expressed or implied, is made by the 
C      USGS as to the accuracy and functioning of the program and
C      related program material, nor shall the fact of distribution
C      constitute any such warranty, and no responsibility is
C      assumed by the USGS in connection therewith
C
C---SPECIFICATIONS
C
C---THE FOLLOWING CARD MUST BE CHANGED IF PROBLEM DIMENSIONS ARE
C   GREATER THAN 1,000. ALSO CHANGE VALUE OF IMAXX IN
C   SUBROUTINE DATAIO
      PARAMETER (IMAXX=1000)
C
      IMPLICIT DOUBLE PRECISION (A-H, O-Z)
      DIMENSION XTIME(IMAXX),STAGE(IMAXX),RECH(IMAXX)
      DIMENSION FH(IMAXX),FQ(IMAXX),H(IMAXX),SEEP(IMAXX),
     2 BANK(IMAXX),BANKV(IMAXX),SEEPT(IMAXX),HNET(IMAXX),
     3 QNET(IMAXX)
C---COMMON STATEMENTS
      COMMON /IOUNIT/ IN,IO,IP
      COMMON /PAR1/ ISTRESS,NT
      COMMON /PAR2/ IXL,IAQ,IXA,NS,IOWS
      COMMON /PAR3/ XZERO,XLL,XSTREAM,XAA,DELT
      COMMON /PAR4/ AKX,XKD,AS,ASY,AB
      COMMON /PAR5/ X,Z1,Z2,ZP
      COMMON /PAR6/ HINIT,TINIT
      COMMON /PAR7/ XTIME,STAGE,RECH
      COMMON /PAR8/ RERRNR,XTRMS
      COMMON /PAR9/ BETA0,SIGMA,XLLD,XAAD
      COMMON /PAR10/ V(20),XLN2,EXPMAX,NN
      COMMON /PAR11/ XD,ZD1,ZD2,ZD
C
C1--OPEN INPUT, RESULT, AND PLOT FILES
      CALL OFILE(IPLOT)
C
C2--READ AND WRITE INPUT DATA
      CALL DATAIO
C
C3--DEFINE DIMENSIONLESS AND OTHER PARAMETERS
      ASC=AS*AB
      XZEROSQ=XZERO*XZERO
      XD=X/XZERO
      XZEROD=XZERO/AB
      BETA0=XKD*XZEROD*XZEROD
      SIGMA=ASC/ASY
      IF(IOWS.EQ.0)THEN
       ZD1=Z1/AB
       ZD2=Z2/AB
      ENDIF
      IF(IOWS.EQ.1)THEN
       ZD1=0.0D0
       ZD2=1.0D0
      ENDIF
      IF(IOWS.EQ.2)ZD=ZP/AB
      IF(IXA.EQ.1)THEN
       XAAD=XAA/XZERO
      ELSE
       XAAD=0.0D0
      ENDIF
      IF(IXL.EQ.1)THEN
       XLLD=XLL/XZERO
      ELSE
       XLLD=0.0D0
      ENDIF
C
      WRITE(IO,100)
      WRITE(IO,101)XD
      WRITE(IO,102)XZEROD
      IF(IXL.EQ.0)WRITE(IO,103)
      IF(IXL.EQ.1)WRITE(IO,104)XLLD
      WRITE(IO,105)XAAD
      IF(IAQ.EQ.1)THEN
       WRITE(IO,106)BETA0
       WRITE(IO,107)SIGMA
       IF(IOWS.EQ.0.OR.IOWS.EQ.1)THEN
        WRITE(IO,108)ZD1
        WRITE(IO,109)ZD2
       ENDIF
       IF(IOWS.EQ.2)WRITE(IO,110)ZD
      ENDIF
C
C---EXPMAX IS THE MAXIMUM ALLOWABLE ABSOLUTE VALUE OF EXPONENTIAL ARGUMENTS
C
       EXPMAX=708.D0
C
C4--CALL LINVST TO CALCULATE COEFFICIENTS USED FOR THE STEHFEST
C     ALGORITHM
C
       CALL LINVST(V,NS)
       XLN2=DLOG(2.D0)
C
      WRITE(IO,111)
      WRITE(*,112)
C
C5--INITIALIZE RESPONSE AND OTHER ARRAYS
       DO 5 I=1,NT
        H(I)=HINIT
        SEEP(I)=0.0D0
        SEEPT(I)=0.0D0
        BANK(I)=0.0D0
        BANKV(I)=0.0D0
        IF(ISTRESS.EQ.0)THEN
         HNET(I)=STAGE(I)
         QNET(I)=STAGE(I)
        ENDIF
        IF(ISTRESS.EQ.1)THEN
         HNET(I)=RECH(I)
         QNET(I)=-RECH(I)
        ENDIF
        IF(ISTRESS.EQ.2)THEN
         HNET(I)=STAGE(I)+RECH(I)
         QNET(I)=STAGE(I)-RECH(I)
        ENDIF
    5  CONTINUE
C
C6--CALCULATE THE TIME RATE OF CHANGE OF SYSTEM STRESS
       DO 10 I=2,NT
        FH(I-1)=(HNET(I)-HNET(I-1))/DELT
        FQ(I-1)=(QNET(I)-QNET(I-1))/DELT
   10  CONTINUE
C
C7--CALCULATE HEADS, SEEPAGE, AND BANK STORAGE USING CONVOLUTION
       DO 15 JT=1,NT-1
        SUMH=0.0D0
        SUMQ=0.0D0
       DO 20 KT=1,JT
        T=KT*DELT
        TD=(AKX*T)/(AS*XZEROSQ)
C
C8a-IF CONFINED AQUIFER (IAQ=0), CALL LTST1 TO CALCULATE DIMENSIONLESS
C   HEAD AND SEEPAGE FOR DIMENSIONLESS TIME TD
        IF(IAQ.EQ.0)CALL LTST1(TD,HD,QD)
C
C8b-IF WATER-TABLE AQUIFER (IAQ=1), CALL LTST2 TO CALCULATE DIMENSIONLESS
C   HEAD AND SEEPAGE FOR DIMENSIONLESS TIME TD
        IF(IAQ.EQ.1)CALL LTST2(TD,HD,QD)
        IF(DABS(HD).LT.1.D-4)HD=0.0D0
        SUMH=SUMH + FH(JT-KT+1)*HD
        SUMQ=SUMQ + FQ(JT-KT+1)*QD
   20  CONTINUE
C
        H(JT+1)=H(JT+1) + SUMH*DELT
        SEEP(JT+1)=SUMQ*(AKX/XZEROD)*DELT
        SEEPT(JT+1)=2.0D0*SEEP(JT+1)*XSTREAM
        BANK(JT+1)=BANK(JT) - SEEP(JT+1)*DELT
        BANKV(JT+1)=2.0D0*BANK(JT+1)*XSTREAM
C
   15  CONTINUE
C
C9--WRITE RESULTS TO RESULT AND PLOT FILES
      WRITE(IO,113)
C
      IF(IPLOT.EQ.1)WRITE(IP,114)
C
      DO 80 I=1,NT
       T=TINIT+(I-1)*DELT
       WRITE(IO,115)T,H(I),SEEP(I),SEEPT(I),BANK(I),BANKV(I)
       IF(IPLOT.EQ.1)THEN
       WRITE(IP,116)T,H(I),SEEP(I),SEEPT(I),BANK(I),BANKV(I)
       ENDIF
  80   CONTINUE
C
C---FORMAT STATEMENTS
  100 FORMAT(/,/,14X,'DIMENSIONLESS PARAMETERS (CALCULATED BY', 
     2 ' PROGRAM)',/,14X,'-----------------------------------',
     3 '-------------',/)
  101 FORMAT(2X,' DIMENSIONLESS DISTANCE TO WELL (XD): ',
     2 20X,D10.3)
  102 FORMAT(2X,' DIMENSIONLESS DISTANCE TO STREAMBANK (XZEROD): ',
     2 10X,D10.3)
  103 FORMAT(2X,' DIMENSIONLESS WIDTH OF AQUIFER (XLLD): ',
     2 19X,' INFINITE')
  104 FORMAT(2X,' DIMENSIONLESS WIDTH OF AQUIFER (XLLD): ',
     2 18X,D10.3)
  105 FORMAT(2X,' DIMENSIONLESS STREAMBANK LEAKANCE (XAAD): ',
     2 15X,D10.3)
  106 FORMAT(2X,' BETA0: ',50X,D10.3)
  107 FORMAT(2X,' RATIO OF STORATIVITY TO SPECIFIC YIELD',
     2' (SIGMA): ',9X,D10.3)
  108 FORMAT(2X,' DIMENSIONLESS POSITION OF BOTTOM OF SCREENED',
     2 /,3X,' INTERVAL OF OBSERVATION WELL (ZD1): ',20X,D10.3)
  109 FORMAT(2X,' DIMENSIONLESS POSITION OF TOP OF SCREENED',
     2 /,3X,' INTERVAL OF OBSERVATION WELL (ZD2): ',20X,D10.3)
  110 FORMAT(2X, ' DIMENSIONLESS POSITION OF OBSERVATION',
     2 /,3X,' PIEZOMETER (ZD): ',39X,D10.3)
  111 FORMAT(/,/,/,38X,'RESULTS',/,38X,'-------',/)
  112 FORMAT(/,3X,'Calculating aquifer responses ...',/)
  113 FORMAT(/,43X,'TOTAL',7X,'BANK',5X,'BANK-STORAGE',/,
     2 6X,'TIME',9X,'HEAD',7X,'SEEPAGE',5X,'SEEPAGE',5X,'STORAGE',
     3 6X,'VOLUME',/,
     4 6X,'(T)',10X,'(L)',8X,'(L**2/T)',4X,'(L**3/T)',5X,'(L**2)',
     5 6X,'(L**3)',/,
     6 6X,'----',9X,'----',6X,'----------',2X,'----------',4X,
     7 '-------',6X,'------')
  114 FORMAT(8X,'T',12X,'H',10X,'SEEP',8X,'SEEPT',
     2 7X,'BANK',8X,'BANKV')
  115 FORMAT(1X,D13.6,2X,D11.5,2X,D10.4,2X,D10.4,2X,D10.4,
     2 2X,D10.4)
  116 FORMAT(1X,E13.6,2X,E11.5,2X,E10.4,2X,E10.4,2X,E10.4,
     2 2X,E10.4)
C
C10-CLOSE INPUT/RESULT/PLOT FILES, STOP, AND END
      CLOSE(UNIT=IN)
      CLOSE(UNIT=IO)
      IF(IPLOT.EQ.1)CLOSE(UNIT=IP)
      STOP
      END
C
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE OFILE                    *
C      *                                                      *
C      *            VERSION CURRENT AS OF 09/01/98            *
C      *                                                      *
C       ******************************************************
C
C11-SUBROUTINE OFILE OPENS INPUT, RESULT, AND PLOT FILES
C
      SUBROUTINE OFILE(IPLOT)
C
C---SPECIFICATIONS
      CHARACTER*50 IFNAME, OFNAME, PFNAME
      INTEGER IN, IO, IP, N, IPLOT
      COMMON /IOUNIT/ IN,IO,IP
C
      IN = 15
      IO = 16
      IP = 17
C---Write banner to screen:
      WRITE(*,8)
C
C---READ INPUT, RESULT, AND PLOT FILE NAMES
   10 WRITE(*,2)
      READ(*,5) IFNAME
      N=LENCHR(IFNAME)
      IF(N.LT.1) GO TO 10
      OPEN(IN,FILE=IFNAME,STATUS='OLD')
C
   11 WRITE(*,3)
      READ(*,5) OFNAME
      N=LENCHR(OFNAME)
      IF(N.LT.1) GO TO 11
      OPEN(IO,FILE=OFNAME)
C
      WRITE(*,4)
      READ(*,5) PFNAME
      N=LENCHR(PFNAME)
      IF(N.LT.1)THEN
       IPLOT=0
       WRITE(*,6)
      ELSE
       IPLOT=1
       OPEN(IP,FILE=PFNAME)
      ENDIF
C
      WRITE(*,7)
C
C---FORMAT STATEMENTS
    2 FORMAT(3X,'Enter name of file containing input data:')
    3 FORMAT(3X,'Enter name of file for program results:')
    4 FORMAT(3X,'Enter name of plot file (return for no plot file):')
    5 FORMAT(A50)
    6 FORMAT(/,3X,'No plot file specified. Results will not be written',
     1' to a plot file.')
    7 FORMAT(/,3X,'File names have been read.')
C---Update 11/24/2009: add FORMAT statement:
    8 FORMAT(10X,'   STWT1 version 1.0, November 24, 2009',/,
     1 3X, 'Computer Program for Analysis of Hydraulic Interaction',/,
     2 3X, ' Between a Stream and Confined or Water-Table Aquifer',/)
C
C---RETURN AND END
      RETURN
      END
C
C       ******************************************************
C      *                                                      *
C      *                    FUNCTION LENCHR                   *
C      *                                                      *
C      *            VERSION CURRENT AS OF 09/01/98            *
C      *                                                      *
C       ******************************************************
C
C12-FUNCTION LENCHR CALCULATES THE LENGTH OF A CHARACTER STRING
C   (CODE FROM R. STEVE REGAN, USGS)
C
      INTEGER FUNCTION LENCHR
     I                       ( STRING )
C
      CHARACTER*(*) STRING
C
C     + + + ARGUMENT DEFINITIONS + + +
C     STRING - Input string to determine length of
C
C     + + + LOCAL VARIABLES + + +
      INTEGER MAX, I
C
C     + + + INTRINSICS + + +
      INTEGER LEN
      INTRINSIC LEN
C
C     + + + END SPECIFICATIONS + + +
C
      MAX = LEN(STRING)
      DO 10 I = MAX, 1, -1
        IF (STRING(I:I).NE.' ') THEN
          LENCHR = I
          GOTO 20
        ENDIF
   10 CONTINUE
      LENCHR = 0
C
   20 RETURN
      END
C
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE DATAIO                   *
C      *                                                      *
C      *            VERSION CURRENT AS OF 09/01/98            *
C      *                                                      *
C       ******************************************************
C
C13-SUBROUTINE DATAIO READS INPUT DATA FROM THE INPUT FILE AND
C   WRITES THIS DATA TO THE RESULT FILE
      SUBROUTINE DATAIO
C
C---SPECIFICATIONS
C
C--THE FOLLOWING CARD MUST BE CHANGED IF PROBLEM DIMENSIONS ARE
C   GREATER THAN 1,000. ALSO CHANGE VALUE OF IMAXX IN
C   MAIN PROGRAM
      PARAMETER (IMAXX=1000)
C
      IMPLICIT DOUBLE PRECISION (A-H, O-Z)
      DIMENSION XTIME(IMAXX),STAGE(IMAXX),RECH(IMAXX)
      CHARACTER STRING*80,TITLE1*70,TITLE2*70               
C---COMMON STATEMENTS
      COMMON /IOUNIT/ IN,IO,IP
      COMMON /PAR1/ ISTRESS,NT
      COMMON /PAR2/ IXL,IAQ,IXA,NS,IOWS
      COMMON /PAR3/ XZERO,XLL,XSTREAM,XAA,DELT
      COMMON /PAR4/ AKX,XKD,AS,ASY,AB
      COMMON /PAR5/ X,Z1,Z2,ZP
      COMMON /PAR6/ HINIT,TINIT
      COMMON /PAR7/ XTIME,STAGE,RECH
      COMMON /PAR8/ RERRNR,XTRMS
      COMMON /PAR9/ BETA0,SIGMA,XLLD,XAAD
C
C13a-WRITE PROGRAM BANNER TO RESULT FILE
      CALL BANNER(IO)
C
C13b-READ INPUT DATA
      READ(IN,'(A80)') STRING
      ILINE=1
      READ(STRING,99,ERR=1000) TITLE1
C
      READ(IN,'(A80)') STRING
      ILINE=2
      READ(STRING,99,ERR=1000) TITLE2
C
      READ(IN,'(A80)') STRING
      ILINE=3
      READ(STRING,*,ERR=1000) ISTRESS, DELT, IPRINT
C
      READ(IN,'(A80)') STRING
      ILINE=4
      READ(STRING,*,ERR=1000) IXL, IAQ, IXA 
C
      READ(IN,'(A80)') STRING
      ILINE=5
      READ(STRING,*,ERR=1000) XZERO, XLL, XAA, XSTREAM
C
      READ(IN,'(A80)') STRING
      ILINE=6
      READ(STRING,*,ERR=1000) AKX, XKD, AS, ASY, AB
C
      READ(IN,'(A80)') STRING
      ILINE=7
      READ(STRING,*,ERR=1000) X, IOWS, Z1, Z2, ZP 
C
      READ(IN,'(A80)') STRING
      ILINE=8
      READ(STRING,*,ERR=1000) HINIT, TINIT
C
      READ(IN,'(A80)') STRING
      ILINE=9
      READ(STRING,*,ERR=1000) NS, RERRNR, XTRMS

      READ(IN,'(A80)') STRING
      ILINE=10
      READ(STRING,*,ERR=1000) NT
C
C13c-READ STRESS DATA
       DO 10 ID=1,NT
         READ(IN,'(A80)') STRING
         ILINE=11
         READ(STRING,*,ERR=1000) XTIME(ID), STAGE(ID), RECH(ID)
  10   CONTINUE
C
C13d-WRITE INPUT DATA TO RESULT FILE
C
C---LINES 1 AND 2
      WRITE(IO,100)TITLE1
      WRITE(IO,100)TITLE2
C
      WRITE(IO,101)
C
C---LINE 3
      IF(ISTRESS.EQ.0)WRITE(IO,102)ISTRESS
      IF(ISTRESS.EQ.1)WRITE(IO,103)ISTRESS
      IF(ISTRESS.EQ.2)WRITE(IO,104)ISTRESS
      IF(ISTRESS.GT.2.OR.ISTRESS.LT.0)THEN
       WRITE(IO,105)
       STOP
      ENDIF
      IF(ISTRESS.EQ.1.OR.ISTRESS.EQ.2)THEN
       IF(IAQ.NE.1)THEN
        WRITE(IO,106)
        STOP
       ENDIF
      ENDIF
C
      WRITE(IO,107)DELT
C
      IF(IPRINT.EQ.0)WRITE(IO,108)IPRINT
      IF(IPRINT.EQ.1)WRITE(IO,109)IPRINT
      IF(IPRINT.GT.1)THEN
       WRITE(IO,110)
       STOP
      ENDIF
C
C---LINES 4 AND 5
      WRITE(IO,111)
C
      IF(IXL.EQ.0)WRITE(IO,112)IXL
      IF(IXL.EQ.1)WRITE(IO,113)IXL
      IF(IXL.GT.1)THEN
       WRITE(IO,114)
       STOP
      ENDIF
C
      IF(IAQ.EQ.0)WRITE(IO,115)IAQ
      IF(IAQ.EQ.1)WRITE(IO,116)IAQ
      IF(IAQ.GT.1)THEN
        WRITE(IO,117)
        STOP
      ENDIF
C
      IF(IXA.EQ.0)WRITE(IO,118)IXA
      IF(IXA.EQ.1)WRITE(IO,119)IXA
      IF(IXA.GT.1)THEN
       WRITE(IO,120)
       STOP
      ENDIF
C
      WRITE(IO,121)XZERO
      IF(XZERO.LE.0.0D0)THEN
        WRITE(IO,122)
        STOP
      ENDIF
C
      IF(IXL.EQ.1)WRITE(IO,123)XLL
      IF(IXL.EQ.1)THEN
       IF(XLL.LE.0.0D0)THEN
        WRITE(IO,124)
        STOP
       ENDIF
      ENDIF
C
      IF(IXA.EQ.1)WRITE(IO,125)XAA
      IF(IXA.EQ.1)THEN
       IF(XAA.LE.0.0D0)THEN
        WRITE(IO,126)
        STOP
       ENDIF
      ENDIF
C
      WRITE(IO,127)XSTREAM
      IF(XSTREAM.LE.0.0D0)THEN
       WRITE(IO,128)
       STOP
      ENDIF
C
C---LINE 6
      WRITE(IO,129)
C
      WRITE(IO,130)AKX
      WRITE(IO,131)XKD
      WRITE(IO,132)AS
      WRITE(IO,133)ASY
      WRITE(IO,134)AB
C
      IF(AKX.LE.0.0D0)THEN
       WRITE(IO,135)
       STOP
      ENDIF
      IF(XKD.LE.0.0D0)THEN
       WRITE(IO,135)
       STOP
      ENDIF
      IF(AS.LE.0.0D0)THEN
       WRITE(IO,135)
       STOP
      ENDIF
      IF(ASY.LE.0.0D0)THEN
       WRITE(IO,135)
       STOP
      ENDIF
      IF(AB.LE.0.0D0)THEN
       WRITE(IO,135)
       STOP
      ENDIF
C
C---LINE 7
      WRITE(IO,136)
C
      WRITE(IO,137)X
      IF(IOWS.EQ.0)THEN
       WRITE(IO,138)IOWS
       WRITE(IO,139)Z1
       WRITE(IO,140)Z2
      ENDIF
      IF(IOWS.EQ.1)THEN
       WRITE(IO,141)IOWS
       WRITE(IO,139)Z1
       WRITE(IO,140)Z2
      ENDIF
      IF(IOWS.EQ.2)THEN
       WRITE(IO,142)IOWS
       WRITE(IO,143)ZP
      ENDIF
      IF(IOWS.EQ.1)THEN
       BCALC=Z2-Z1
       IF(BCALC.NE.AB)THEN
        WRITE(IO,144)
        STOP
       ENDIF
      ENDIF
C
C---LINE 8
      WRITE(IO,145)
C
      WRITE(IO,146)HINIT
      WRITE(IO,147)TINIT
C
C---LINE 9
      WRITE(IO,148)
      WRITE(IO,149)NS
      WRITE(IO,150)RERRNR
      WRITE(IO,151)XTRMS
C
C---LINES 10 AND HIGHER
      WRITE(IO,152)
      WRITE(IO,153)NT
C
      IF(IPRINT.EQ.0)WRITE(IO,154)
C 
      IF(IPRINT.EQ.1)THEN
      WRITE(IO,155)
        DO 35 ID=1,NT
         WRITE(IO,156)XTIME(ID),STAGE(ID),RECH(ID)
  35    CONTINUE
      ENDIF
C
C--FORMAT STATEMENTS
   99 FORMAT(A70)
  100 FORMAT(5X,A70)
  101 FORMAT(/,/,20X,'SUMMARY OF INPUT DATA',
     2/,20X,'---------------------'/)
  102 FORMAT(2X,' STRESS TYPE (ISTRESS): ',10X,I5,
     2' (stream-stage fluctuations)')
  103 FORMAT(2X,' STRESS TYPE (ISTRESS): ',10X,I5,
     2' (recharge/leakage)')
  104 FORMAT(2X,' STRESS TYPE (ISTRESS): ',10X,I5,
     2' (stream-stage and recharge/leakage)')
  105 FORMAT(2X,' ISTRESS NOT EQUAL TO 0, 1, OR 2. PROGRAM STOPPED')
  106 FORMAT(/,2X,' ISTRESS EQUALS 1 OR 2 (RECHARGE) AND AQUIFER',
     2' IS NOT WATER TABLE.',/,2X,' RECHARGE IS SIMULATED ONLY',
     3' WHEN A WATER TABLE IS PRESENT.',/,2X,' PROGRAM STOPPED.')
  107 FORMAT(2X,' TIME-STEP SIZE (DELT):',12X,D12.3,' (units of time)')
  108 FORMAT(2X,' PRINTING CODE (IPRINT): ',9X,I5,
     2' (stress data not printed)')
  109 FORMAT(2X,' PRINTING CODE (IPRINT): ',9X,I5,
     2' (stress data printed)')
  110 FORMAT(3X,'PRINTING CODE (IPRINT) IS INVALID. PROGRAM STOPPED.')
  111 FORMAT(/,' AQUIFER AND STREAMBANK CHARACTERISTICS
     2 (INPUT LINES 4 AND 5)')
  112 FORMAT(2X,' AQUIFER EXTENT (IXL): ',11X,I5,
     2' (semi infinite)')
  113 FORMAT(2X,' AQUIFER EXTENT (IXL): ',11X,I5,
     2' (finite width)')
  114 FORMAT(3X,'AQUIFER EXTENT (IXL) IS INVALID. PROGRAM STOPPED.')
  115 FORMAT(2X,' AQUIFER TYPE (IAQ): ',13X,I5,
     2' (confined)')
  116 FORMAT(2X,' AQUIFER TYPE (IAQ): ',13X,I5,
     2' (water table)')
  117 FORMAT(3X,'AQUIFER TYPE (IAQ) IS INVALID. PROGRAM STOPPED.') 
  118 FORMAT(2X,' STREAMBANK CODE (IXA): ',10X,I5,
     2' (semipervious streambank absent)')
  119 FORMAT(2X,' STREAMBANK CODE (IXA): ',10X,I5,
     2' (semipervious streambank simulated)')
  120 FORMAT(3X,'STREAMBANK CODE (IXA) INVALID. PROGRAM STOPPED.')
  121 FORMAT(2X,' STREAM HALF WIDTH (XZERO): ',7X,D12.3,
     2' (units of length)')
  122 FORMAT(3X,'STREAM HALF WIDTH (XZERO) IS LESS THAN OR EQUAL',
     2 ' TO ZERO. PROGRAM STOPPED')
  123 FORMAT(2X,' WIDTH OF AQUIFER (XLL): ',10X,D12.3,
     2' (units of length)')
  124 FORMAT(2X,' AQUIFER WIDTH (XLL) LESS THAN OR EQUAL
     2 TO ZERO. PROGRAM STOPPED.')
  125 FORMAT(2X,' STREAMBANK LEAKANCE (XAA): ',9X,D10.3,
     2' (units of length)')
  126 FORMAT(3X,'STREAMBANK LEAKANCE (XAA) LESS THAN OR EQUAL',
     2' TO ZERO.',/,3X,' PROGRAM STOPPED.')
  127 FORMAT(2X,' LENGTH OF STREAM (XSTREAM): ',6X,D12.3,
     2' (units of length)')
  128 FORMAT(3X,'STREAM LENGTH (XSTREAM) IS LESS THAN OR EQUAL TO',
     2' ZERO. PROGRAM STOPPED.')
  129 FORMAT(/,' AQUIFER PROPERTIES (INPUT LINE 6) ')
  130 FORMAT(2X,' HORIZONTAL HYDRAULIC',/,3X,
     2' CONDUCTIVITY (AKX): ',13X,D12.3,' (units of length per time)')
  131 FORMAT(2X,' RATIO OF VERTICAL TO HORIZONTAL',/,3X,
     2' HYDRAULIC CONDUCTIVITY (XKD): ',3X,D12.3,' (dimensionless)')
  132 FORMAT(2X,' SPECIFIC STORAGE (AS): ',11X,D12.3,
     2' (units of inverse length)')
  133 FORMAT(2X,' SPECIFIC YIELD (ASY): ',12X,D12.3,
     2' (dimensionless)')
  134 FORMAT(2X,' SATURATED THICKNESS (AB): ',8X,D12.3,
     2' (units of length)')
  135 FORMAT(3X,'A HYDRAULIC PROPERTY OF THE AQUIFER (INPUT LINE 6)',
     2 ' IS LESS THAN OR',/,3X,' EQUAL TO ZERO. PROGRAM STOPPED.')
  136 FORMAT(/,' OBSERVATION-WELL DATA (INPUT LINE 7) ')
  137 FORMAT(2X,' DISTANCE TO OBSERVATION WELL (X): ',2X,D10.3,
     2' (units of length)')
  138 FORMAT(2X,' TYPE OF OBSERVATION WELL (IOWS): ',I5,
     2' (partially penetrating)')
  139 FORMAT(2X,' POSITION OF BOTTOM OF SCREENED',/,
     2 3X,' INTERVAL OF OBSERVATION WELL (Z1): ',D10.3,
     3' (units of length)')
  140 FORMAT(2X,' POSITION OF TOP OF SCREENED',/,
     2 3X,' INTERVAL OF OBSERVATION WELL (Z2): ',D10.3,
     3' (units of length)')
  141 FORMAT(2X,' TYPE OF OBSERVATION WELL (IOWS): ',I5,
     2' (fully penetrating)')
  142 FORMAT(2X,' TYPE OF OBSERVATION WELL (IOWS): ',I5,
     2' (observation piezometer)')
  143 FORMAT(2X,' POSITION OF OBSERVATION ',/,
     2 3X,' PIEZOMETER (ZP): ',16X,D12.3,' (units of length)')
  144 FORMAT(/,2X,'Z2 - Z1 DOES NOT EQUAL SATURATED THICKNESS',
     2 ' SPECIFIED FOR AQUIFER.',/,' MODIFY Z1 OR Z2 (LINE 7)',
     3 ' OR AB (LINE 6). PROGRAM STOPPED.')
  145 FORMAT(/,' INITIAL CONDITIONS (INPUT LINE 8)')
  146 FORMAT(2X,' INITIAL HEAD AT WELL (HINIT): ',4X,D12.3,
     2' (units of length)')
  147 FORMAT(2X,' START TIME OF SIMULATION (TINIT): ',3X,D9.3,
     2' (units of time)')
  148 FORMAT(/,' PROGRAM SOLUTION VARIABLES (INPUT LINE 9) ')
  149 FORMAT(2X,' NUMBER OF STEHFEST TERMS (NS): ',16X,I5)
  150 FORMAT(2X,' RELATIVE ERROR FOR NEWTON-RAPHSON (RERRNR): ',
     2 4X,D12.3)
  151 FORMAT(2X,' FACTOR DETERMINING NUMBER OF TERMS IN THE',/,3X,
     2' FINITE SUMS FOR HEAD AND SEEPAGE (XTRMS): ',5X,D12.3)
  152 FORMAT(/,/,20X,'SUMMARY OF STRESS DATA',/,
     2 20X,'----------------------')
  153 FORMAT(/,2X,' NUMBER OF SPECIFIED TIME STEPS (NT): ',9X,I5)
  154 FORMAT(2X,' STRESS DATA NOT PRINTED ')
  155 FORMAT(/,10X,'TIME        STAGE         RECH',/,
     2'          ----        -----         ----')
  156 FORMAT(7X,D10.4,3X,D10.4,3X,D10.4)
C
      RETURN
C---CALL RDERR FOR INPUT READ ERRORS
 1000 CALL RDERR(IO,STRING,ILINE)
      END
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE BANNER                   *
C      *                                                      *
C      *            VERSION CURRENT AS OF 09/01/98            *
C      *                                                      *
C       ******************************************************
C
C14-SUBROUTINE BANNER WRITES A PROGRAM BANNER TO RESULT FILE
      SUBROUTINE BANNER(IO)
      WRITE(IO,100)
 100  FORMAT(/,10X,
     2'      *****************************************************',/,
     3 10X,
     4'      *                                                   *',/,
     5 10X,
     6'      *         ****  U.S. GEOLOGICAL SURVEY  ****        *',/,
     7 10X,
     8'      *                                                   *',/,
     9 10X,
     &'      *          **** STWT1: PROGRAM OUTPUT ****          *',/,
     1 10X,
     2'      *                                                   *',/,
     3 10X,
     4'      * TWO-DIMENSIONAL MODEL OF STREAM-AQUIFER HYDRAULIC *',/,
     5 10X,
     6'      *                                                   *',/,
     7 10X,
     8'      * INTERACTION FOR CONFINED AND WATER-TABLE AQUIFERS *',/,
     9 10X,
     &'      *                                                   *',/,
     1 10X,
     2'      *       BOUNDED BY A FULLY PENETRATING STREAM       *',/,
     3 10X,
     4'      *                                                   *',/,
     5 10X,
     6'      *           VERSION CURRENT AS OF 09/01/98          *',/,
     7 10X,
     8'      *                                                   *',/,
     9 10X,
     &'      *****************************************************',
     1/,/)
C
      RETURN
      END
C
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE RDERR                    *
C      *                                                      *
C      *            VERSION CURRENT AS OF 09/01/98            *
C      *                                                      *
C       ******************************************************
C
C15-SUBROUTINE RDERR WRITES AN ERROR MESSAGE TO THE RESULT FILE
C   AND STOPS PROGRAM EXECUTION
C
      SUBROUTINE RDERR(IO,STRING,ILINE)
C
C---SPECIFICATIONS
      CHARACTER STRING*80,VAR(11)*40
      DATA VAR/' TITLE1',
     2         ' TITLE2',
     3         ' ISTRESS  DELT  IPRINT',
     4         ' IXL  IAQ  IXA',
     5         ' XZERO  XLL  XAA  XSTREAM',
     6         ' AKX  XKD  AS  ASY  AB',
     7         ' X  IOWS  Z1  Z2  ZP',
     8         ' HINIT  TINIT',
     9         ' NS  RERRNR  XTRMS',
     &         ' NT',
     1         ' TIME-STRESS DATA'/
      WRITE(IO,1)ILINE
      WRITE(IO,'(A80)')STRING
      WRITE(IO,2) VAR(ILINE)
      WRITE(IO,3)

   1  FORMAT(' Aborting due to error in line from input file:',
     2 2X,I5)
   2  FORMAT(' While attempting to read variables',A40)
   3  FORMAT(' Check for incorrect positions or data types...')
      STOP
      END
C
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE LINVST                   *
C      *                                                      *
C      *            VERSION CURRENT AS OF 09/01/98            *
C      *                                                      *
C       ******************************************************
C
C16-SUBROUTINE LINVST CALCULATES COEFFICIENTS USED FOR THE
C   STEHFEST ALGORITHM
C
       SUBROUTINE LINVST(V,NS)
C
C---SPECIFICATIONS
       IMPLICIT DOUBLE PRECISION (A-H,O-Z)
       DIMENSION G(20),V(20),HS(20)
C
       G(1)=1.D0
       NH=NS/2
        DO 1 IS=2,NS
1      G(IS)=G(IS-1)*IS
       HS(1)=2.D0/G(NH-1)
        DO 3 IS=2,NH
       FI=IS
       IF(IS.EQ.NH) GO TO 2
       HS(IS)=FI**(NH)*G(2*IS)/(G(NH-IS)*G(IS)*G(IS-1))
       GO TO 3
2      HS(IS)=FI**(NH)*G(2*IS)/(G(IS)*G(IS-1))
3       CONTINUE
       SN=2*(NH-NH/2*2)-1
        DO 4 IS=1,NS
       V(IS)=0.D0
       K1=(IS+1)/2
       K2=IS
       IF(K2.GT.NH)K2=NH
        DO 5 KS=K1,K2
       IF(2*KS-IS.EQ.0) GO TO 6
       IF(IS.EQ.KS)GO TO 7
       V(IS)=V(IS)+HS(KS)/(G(IS-KS)*G(2*KS-IS))
       GO TO 5
6      V(IS)=V(IS)+HS(KS)/(G(IS-KS))
       GO TO 5
7      V(IS)=V(IS)+HS(KS)/G(2*KS-IS)
5       CONTINUE
       V(IS)=SN*V(IS)
       SN=-SN
4       CONTINUE
       RETURN
       END
C
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE LTST1                    *
C      *                                                      *
C      *            VERSION CURRENT AS OF 09/01/98            *
C      *                                                      *
C       ******************************************************
C
C17-SUBROUTINE LTST1 CALCULATES THE LAPLACE TRANSFORM SOLUTIONS FOR
C   HEADS AND SEEPAGE FOR CONFINED AQUIFERS BOUNDED BY A FULLY 
C   PENETRATING STREAM. AQUIFERS MAY BE SEMI-INFINITE OR FINITE WIDTH
C   AND MAY INCLUDE A SEMI-PERVIOUS STREAMBANK.
C
       SUBROUTINE LTST1(TD,HDT,QTD)
C
C---SPECIFICATIONS
       IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C---COMMON STATEMENTS
      COMMON /IOUNIT/ IN,IO,IP
      COMMON /PAR2/ IXL,IAQ,IXA,NS,IOWS
      COMMON /PAR8/ RERRNR,XTRMS
      COMMON /PAR9/ BETA0,SIGMA,XLLD,XAAD
      COMMON /PAR10/ V(20),XLN2,EXPMAX,NN
      COMMON /PAR11/ XD,ZD1,ZD2,ZD
C
       XP=0.D0
       XPQ=0.D0
      DO 1 I=1,NS
       PP=XLN2*I/TD
       C1=DSQRT(PP)
       C2=PP*(1.D0+C1*XAAD)
       CAQ=-C1/C2
C
C17a-CALCULATE WIDTH TERM.
C     IF IXL.EQ.0, THEN FF = 1.0
C     IF IXL.EQ.1, THEN FF = EXPONENTIALS 
C
       IF(IXL.EQ.0) FF=1.D0
       IF(IXL.EQ.1) THEN
        FNUM=1.D0+DEXP(-2.D0*C1*(XLLD-XD))
        FDEN=1.D0+DEXP(-2.D0*C1*(XLLD-1.D0))
        FF=FNUM/FDEN
        C2=PP*(1.D0+C1*XAAD*DTANH(C1*(XLLD-1.D0)))
        C3=FDEN
        C4=C2*C3
        CAQ=-(C1/C4)*(1.D0-DEXP(-2.D0*C1*(XLLD-1.D0)))
       ENDIF
C
       CA=C1*(XD-1.D0)
       IF(CA.GT.EXPMAX) CA=EXPMAX
C
C17b-CALCULATE HEAD AND SEEPAGE TERMS
C
       RE0=FF*DEXP(-CA)
       RE0Q=CAQ
       PDL=RE0/C2
       PDLQ=RE0Q
      XP=XP+V(I)*PDL
1     XPQ=XPQ+V(I)*PDLQ
       HDT=XP*XLN2/TD
       QTD=XPQ*XLN2/TD
C
C17c-RETURN TO MAIN PROGRAM
       RETURN
       END
C
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE LTST2                    *
C      *                                                      *
C      *            VERSION CURRENT AS OF 09/01/98            *
C      *                                                      *
C       ******************************************************
C
C18-SUBROUTINE LTST2 CALCULATES THE LAPLACE TRANSFORM SOLUTIONS FOR
C   HEADS AND SEEPAGE FOR WATER-TABLE AQUIFERS BOUNDED BY A FULLY 
C   PENETRATING STREAM. AQUIFERS MAY BE SEMI-INFINITE OR FINITE WIDTH
C   AND MAY INCLUDE A SEMI-PERVIOUS STREAMBANK.
C
       SUBROUTINE LTST2(TD,HWT,QWT)
C
C---SPECIFICATIONS
       IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C---COMMON STATEMENTS
      COMMON /IOUNIT/ IN,IO,IP
      COMMON /PAR2/ IXL,IAQ,IXA,NS,IOWS
      COMMON /PAR8/ RERRNR,XTRMS
      COMMON /PAR9/ BETA0,SIGMA,XLLD,XAAD
      COMMON /PAR10/ V(20),XLN2,EXPMAX,NN
      COMMON /PAR11/ XD,ZD1,ZD2,ZD
C
C18a-EMPIRICAL ESTIMATE OF NECESSARY NUMBER OF XN TERMS NEEDED FOR 
C    THE FINITE SUMS. (SMALL VALUES OF BETA AND TD REQUIRE MORE
C    TERMS THAN DO LARGE VALUES.)
C
       BETA=BETA0*XD*XD
       XN_MAX=XTRMS*2.**((-DLOG10(BETA)-2.0))
       NN=XN_MAX
       IF(NN.LT.6)NN=6
C
       PI=3.141592653589793D0
C
       XP=0.D0
       XPQ=0.D0
      DO 1 I=1,NS
       PP=XLN2*I/TD
       RHS=PP/(SIGMA*BETA0)
       SUMM=0.D0
       SUMMQ=0.D0
       XN=0.D0
10     XN=XN+1.D0
C
C18b-ASSIGN A STARTING POINT FOR EPS
       IF(IDNINT(XN).GT.1) GOTO 15
       IF(RHS.LT.1.0D0)EPS=DSQRT(RHS)
       IF(RHS.GE.1.0D0)EPS=DATAN(RHS)
15     IF(IDNINT(XN).GT.1)EPS=EPS0+PI
C
       SUMT=SUMM
       SUMTQ=SUMMQ
C
C18c-CALCULATE EPSILON FOR CURRENT VALUE OF PP USING NEWTON-RAPHSON
C    TECHNIQUE
C
       NNR=0
30     EPS0=EPS
       NNR=NNR+1
       IF(NNR.GT.100)WRITE(IO,100)
       IF(NNR.GT.100)STOP
       A1=DSIN(EPS0)
       A2=DCOS(EPS0)
       F=EPS0*A1-RHS*A2
       FP=EPS0*A2+A1+RHS*A1
       EPS=EPS0-F/FP
       IF(DABS(EPS-EPS0).GT.RERRNR*EPS) GOTO 30
C
C18d-CALCULATE QN TERM
       QN=DSQRT(BETA0*EPS*EPS+PP)
       QNXD=QN*(XD-1.D0)
       IF(QN.GT.EXPMAX) QN=EXPMAX
       IF(QNXD.GT.EXPMAX) QNXD=EXPMAX
       SINE=DSIN(EPS)
C
C18e-CALCULATE WIDTH TERM.
C   IF IXL.EQ.0, THEN SEMI-INFINITE AQUIFER, FN=1.0
C   IF IXL.EQ.1, THEN FINITE-WIDTH AQUIFER, FN=EXPONENTIALS
C
       IF(IXL.EQ.0) FN=1.D0
       IF(IXL.EQ.1) THEN
        FNUM=1.D0+DEXP(-2.D0*QN*(XLLD-XD))
        FDEN=1.D0+DEXP(-2.D0*QN*(XLLD-1.D0))
        FN=FNUM/FDEN
       ENDIF
C
       RE0=FN*DEXP(-QN*(XD-1.D0))
C
C18f-CALCULATE SEEPAGE TERMS
C
       XAD=XAAD
       IF(IXL.EQ.0) FNQ=-1.D0
       IF(IXL.EQ.1) THEN
        XAD=XAAD*DTANH(QN*(XLLD-1.D0))
        FNUMQ=DEXP(-2.D0*QN*(XLLD-1.D0)) - 1.0D0
        FDENQ=DEXP(-2.D0*QN*(XLLD-1.D0)) + 1.0D0
        FNQ=FNUMQ/FDENQ
       ENDIF
       RE0Q=FNQ*QN
C
       XDEN=(1.D0+QN*XAD)*( EPS+0.5D0*DSIN(2.D0*EPS))
C
C18g-IF IOWS.EQ.0, THEN PARTIALLY PENETRATING OBSERVATION WELL
C
       IF(IOWS.EQ.0)THEN 
        XNUM=RE0*SINE*(DSIN(EPS*ZD2)
     1   -DSIN(EPS*ZD1))/(EPS*(ZD2-ZD1))
        SUMM=SUMT+XNUM/XDEN
       ENDIF
C
C18h-IF IOWS.EQ.1, THEN FULLY PENETRATING OBSERVATION WELL
C
       IF(IOWS.EQ.1)THEN 
        XNUM=RE0*SINE*DSIN(EPS)/EPS
        SUMM=SUMT+XNUM/XDEN
       ENDIF
C
C18i-IF IOWS.EQ.2, THEN OBSERVATION PIEZOMETER
C
       IF(IOWS.EQ.2) THEN
        XNUM=RE0*SINE*DCOS(EPS*ZD)
        SUMM=SUMT+XNUM/XDEN
       ENDIF
C
        XNUMQ=RE0Q*SINE*DSIN(EPS)/EPS
        SUMMQ=SUMTQ+XNUMQ/XDEN
C
C18j-IF NECESSARY NUMBER OF FINITE-SUMMATION TERMS HAVE BEEN SUMMED,
C    THEN CONTINUE; ELSE, CONTINUE SUMMATION
       IF(IDNINT(XN).EQ.NN) GOTO 40
       GOTO 10
40     CONTINUE
C
C18k-CALCULATE HEAD AND SEEPAGE TERMS. SEEPAGE INTO AQUIFER
C    IS NEGATIVE.
       PDL=SUMM/PP
       PDLQ=SUMMQ/PP
      XP=XP+V(I)*PDL
1     XPQ=XPQ+V(I)*PDLQ
       HWT=2.D0*XP*XLN2/TD
       QWT=2.D0*XPQ*XLN2/TD
C
C---FORMAT STATEMENTS
  100 FORMAT(' PROGRAM STOPPED BECAUSE NEWTON-RAPHSON ITERATIONS',
     2' EXCEED 100')
C
C18l-RETURN TO MAIN PROGRAM
       RETURN
       END
